Module accounts

Module accounts 

An Anchor generated module, providing a set of structs mirroring the structs deriving Accounts, where each field is a Pubkey. This is useful for specifying accounts for a client.

Structs

AccrueMarket
Generated client accounts for AccrueMarket.
CloseAccount
Generated client accounts for CloseAccount.
ConvertReleasedPnl
Generated client accounts for ConvertReleasedPnl.
Crank
Generated client accounts for Crank.
Deposit
Generated client accounts for Deposit.
DepositFeeCredits
Generated client accounts for DepositFeeCredits.
InitializeMarket
Generated client accounts for InitializeMarket.
Liquidate
Generated client accounts for Liquidate.
ReclaimAccount
Generated client accounts for ReclaimAccount.
Settle
Generated client accounts for Settle.
TopUpInsurance
Generated client accounts for TopUpInsurance.
Trade
Generated client accounts for Trade.
UpdateMatcher
Generated client accounts for UpdateMatcher.
UpdateOracle
Generated client accounts for UpdateOracle.
Withdraw
Generated client accounts for Withdraw.
WithdrawInsurance
Generated client accounts for WithdrawInsurance.