pub struct AccrueMarket {
pub signer: Pubkey,
pub market: Pubkey,
pub oracle: Pubkey,
}Expand description
Generated client accounts for AccrueMarket.
Fields
signer: Pubkeymarket: Pubkeyoracle: PubkeyTrait Implementations
Sourceimpl BorshSerialize for AccrueMarket
impl BorshSerialize for AccrueMarket
Sourceimpl ToAccountMetas for AccrueMarket
impl ToAccountMetas for AccrueMarket
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for AccrueMarket
impl RefUnwindSafe for AccrueMarket
impl Send for AccrueMarket
impl Sync for AccrueMarket
impl Unpin for AccrueMarket
impl UnsafeUnpin for AccrueMarket
impl UnwindSafe for AccrueMarket