pub struct ConvertReleasedPnl {
pub user: Pubkey,
pub market: Pubkey,
pub oracle: Pubkey,
}Expand description
Generated client accounts for ConvertReleasedPnl.
Fields
user: Pubkeymarket: Pubkeyoracle: PubkeyTrait Implementations
Sourceimpl BorshSerialize for ConvertReleasedPnl
impl BorshSerialize for ConvertReleasedPnl
Sourceimpl ToAccountMetas for ConvertReleasedPnl
impl ToAccountMetas for ConvertReleasedPnl
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for ConvertReleasedPnl
impl RefUnwindSafe for ConvertReleasedPnl
impl Send for ConvertReleasedPnl
impl Sync for ConvertReleasedPnl
impl Unpin for ConvertReleasedPnl
impl UnsafeUnpin for ConvertReleasedPnl
impl UnwindSafe for ConvertReleasedPnl