pub struct Deposit {
pub user: Pubkey,
pub market: Pubkey,
pub mint: Pubkey,
pub user_token_account: Pubkey,
pub vault: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for Deposit.
Fields
user: Pubkeymarket: Pubkeymint: PubkeyThe collateral mint for this market.
user_token_account: PubkeyUser’s token account to transfer from.
vault: PubkeyVault token account to transfer into.
token_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for Deposit
impl BorshSerialize for Deposit
Sourceimpl ToAccountMetas for Deposit
impl ToAccountMetas for Deposit
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for Deposit
impl RefUnwindSafe for Deposit
impl Send for Deposit
impl Sync for Deposit
impl Unpin for Deposit
impl UnsafeUnpin for Deposit
impl UnwindSafe for Deposit