pub struct DepositFeeCredits {
pub user: Pubkey,
pub market: Pubkey,
pub mint: Pubkey,
pub user_token_account: Pubkey,
pub vault: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for DepositFeeCredits.
Fields
user: Pubkeymarket: Pubkeymint: Pubkeyuser_token_account: PubkeyUser’s token account to transfer from.
vault: PubkeyVault token account to transfer into.
token_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for DepositFeeCredits
impl BorshSerialize for DepositFeeCredits
Sourceimpl ToAccountMetas for DepositFeeCredits
impl ToAccountMetas for DepositFeeCredits
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for DepositFeeCredits
impl RefUnwindSafe for DepositFeeCredits
impl Send for DepositFeeCredits
impl Sync for DepositFeeCredits
impl Unpin for DepositFeeCredits
impl UnsafeUnpin for DepositFeeCredits
impl UnwindSafe for DepositFeeCredits