pub struct InitializeMarket {
pub authority: Pubkey,
pub market: Pubkey,
pub mint: Pubkey,
pub vault: Pubkey,
pub oracle: Pubkey,
pub matcher: Pubkey,
pub token_program: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for InitializeMarket.
Fields
market: Pubkeywith size = MARKET_ACCOUNT_SIZE and owner = this program. Large accounts (>10 KB) cannot be created via CPI due to the realloc limit, so the client must create the account before calling initialize_market.
mint: PubkeyThe SPL token mint for this market’s collateral (e.g. USDC).
vault: PubkeyVault token account — holds all deposited collateral for this market.
oracle: Pubkeymatcher: PubkeyMatcher authority — the only signer allowed to submit trades.
token_program: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for InitializeMarket
impl BorshSerialize for InitializeMarket
Sourceimpl ToAccountMetas for InitializeMarket
impl ToAccountMetas for InitializeMarket
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for InitializeMarket
impl RefUnwindSafe for InitializeMarket
impl Send for InitializeMarket
impl Sync for InitializeMarket
impl Unpin for InitializeMarket
impl UnsafeUnpin for InitializeMarket
impl UnwindSafe for InitializeMarket