pub struct Liquidate {
pub liquidator: Pubkey,
pub market: Pubkey,
}Expand description
Generated client accounts for Liquidate.
Fields
liquidator: PubkeyPermissionless — anyone can liquidate.
market: PubkeyTrait Implementations
Sourceimpl BorshSerialize for Liquidate
impl BorshSerialize for Liquidate
Sourceimpl ToAccountMetas for Liquidate
impl ToAccountMetas for Liquidate
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for Liquidate
impl RefUnwindSafe for Liquidate
impl Send for Liquidate
impl Sync for Liquidate
impl Unpin for Liquidate
impl UnsafeUnpin for Liquidate
impl UnwindSafe for Liquidate