pub struct ReclaimAccount {
pub reclaimer: Pubkey,
pub market: Pubkey,
}Expand description
Generated client accounts for ReclaimAccount.
Fields
reclaimer: PubkeyPermissionless — anyone can reclaim dead accounts.
market: PubkeyTrait Implementations
Sourceimpl BorshSerialize for ReclaimAccount
impl BorshSerialize for ReclaimAccount
Sourceimpl ToAccountMetas for ReclaimAccount
impl ToAccountMetas for ReclaimAccount
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for ReclaimAccount
impl RefUnwindSafe for ReclaimAccount
impl Send for ReclaimAccount
impl Sync for ReclaimAccount
impl Unpin for ReclaimAccount
impl UnsafeUnpin for ReclaimAccount
impl UnwindSafe for ReclaimAccount