pub struct Settle {
pub user: Pubkey,
pub market: Pubkey,
}Expand description
Generated client accounts for Settle.
Fields
user: Pubkeymarket: PubkeyTrait Implementations
Sourceimpl BorshSerialize for Settle
impl BorshSerialize for Settle
Sourceimpl ToAccountMetas for Settle
impl ToAccountMetas for Settle
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for Settle
impl RefUnwindSafe for Settle
impl Send for Settle
impl Sync for Settle
impl Unpin for Settle
impl UnsafeUnpin for Settle
impl UnwindSafe for Settle