pub struct Trade {
pub signer: Pubkey,
pub market: Pubkey,
}Expand description
Generated client accounts for Trade.
Fields
signer: PubkeyMatcher authority — must match the matcher stored in the market header.
market: PubkeyTrait Implementations
Sourceimpl BorshSerialize for Trade
impl BorshSerialize for Trade
Sourceimpl ToAccountMetas for Trade
impl ToAccountMetas for Trade
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for Trade
impl RefUnwindSafe for Trade
impl Send for Trade
impl Sync for Trade
impl Unpin for Trade
impl UnsafeUnpin for Trade
impl UnwindSafe for Trade