pub struct TransferAuthority {
pub authority: Pubkey,
pub market: Pubkey,
}Expand description
Generated client accounts for TransferAuthority.
Fields
market: PubkeyTrait Implementations
Sourceimpl BorshSerialize for TransferAuthority
impl BorshSerialize for TransferAuthority
Sourceimpl ToAccountMetas for TransferAuthority
impl ToAccountMetas for TransferAuthority
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for TransferAuthority
impl RefUnwindSafe for TransferAuthority
impl Send for TransferAuthority
impl Sync for TransferAuthority
impl Unpin for TransferAuthority
impl UnsafeUnpin for TransferAuthority
impl UnwindSafe for TransferAuthority