pub struct UpdateMatcher {
pub authority: Pubkey,
pub market: Pubkey,
}Expand description
Generated client accounts for UpdateMatcher.
Fields
market: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdateMatcher
impl BorshSerialize for UpdateMatcher
Sourceimpl ToAccountMetas for UpdateMatcher
impl ToAccountMetas for UpdateMatcher
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdateMatcher
impl RefUnwindSafe for UpdateMatcher
impl Send for UpdateMatcher
impl Sync for UpdateMatcher
impl Unpin for UpdateMatcher
impl UnsafeUnpin for UpdateMatcher
impl UnwindSafe for UpdateMatcher