pub struct UpdateOracle {
pub authority: Pubkey,
pub market: Pubkey,
pub new_oracle: Pubkey,
}Expand description
Generated client accounts for UpdateOracle.
Fields
market: Pubkeynew_oracle: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdateOracle
impl BorshSerialize for UpdateOracle
Sourceimpl ToAccountMetas for UpdateOracle
impl ToAccountMetas for UpdateOracle
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdateOracle
impl RefUnwindSafe for UpdateOracle
impl Send for UpdateOracle
impl Sync for UpdateOracle
impl Unpin for UpdateOracle
impl UnsafeUnpin for UpdateOracle
impl UnwindSafe for UpdateOracle