pub struct WithdrawInsurance {
pub authority: Pubkey,
pub market: Pubkey,
pub mint: Pubkey,
pub authority_token_account: Pubkey,
pub vault: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for WithdrawInsurance.
Fields
market: Pubkeymint: PubkeyAuthority’s token account to receive withdrawn insurance tokens.
vault: PubkeyVault token account to transfer from.
token_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for WithdrawInsurance
impl BorshSerialize for WithdrawInsurance
Sourceimpl ToAccountMetas for WithdrawInsurance
impl ToAccountMetas for WithdrawInsurance
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for WithdrawInsurance
impl RefUnwindSafe for WithdrawInsurance
impl Send for WithdrawInsurance
impl Sync for WithdrawInsurance
impl Unpin for WithdrawInsurance
impl UnsafeUnpin for WithdrawInsurance
impl UnwindSafe for WithdrawInsurance