Module instruction

Module instruction 

An Anchor generated module containing the program’s set of instructions, where each method handler in the #[program] mod is associated with a struct defining the input arguments to the method. These should be used directly, when one wants to serialize Anchor instruction data, for example, when specifying instructions on a client.

Structs

AccrueMarket
Instruction.
CloseAccount
Instruction.
ConvertReleasedPnl
Instruction.
Crank
Instruction.
Deposit
Instruction.
DepositFeeCredits
Instruction.
InitializeMarket
Instruction.
Liquidate
Instruction.
ReclaimAccount
Instruction.
Settle
Instruction.
TopUpInsurance
Instruction.
Trade
Instruction.
UpdateMatcher
Instruction.
UpdateOracle
Instruction.
Withdraw
Instruction.
WithdrawInsurance
Instruction.