pub struct ConvertReleasedPnl {
pub account_idx: u16,
pub x_req: u64,
pub funding_rate: i64,
}Expand description
Instruction.
Fields
account_idx: u16x_req: u64funding_rate: i64Trait Implementations
Sourceimpl BorshDeserialize for ConvertReleasedPnl
impl BorshDeserialize for ConvertReleasedPnl
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ConvertReleasedPnl
impl BorshSerialize for ConvertReleasedPnl
Sourceimpl Discriminator for ConvertReleasedPnl
impl Discriminator for ConvertReleasedPnl
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for ConvertReleasedPnl
impl InstructionData for ConvertReleasedPnl