pub struct Deposit {
pub account_idx: u16,
pub amount: u64,
}Expand description
Instruction.
Fields
account_idx: u16amount: u64Trait Implementations
Sourceimpl BorshDeserialize for Deposit
impl BorshDeserialize for Deposit
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Deposit
impl BorshSerialize for Deposit
Sourceimpl Discriminator for Deposit
impl Discriminator for Deposit
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for Deposit
impl InstructionData for Deposit