pub struct DepositFeeCredits {
pub account_idx: u16,
pub amount: u64,
}Expand description
Instruction.
Fields
account_idx: u16amount: u64Trait Implementations
Sourceimpl BorshDeserialize for DepositFeeCredits
impl BorshDeserialize for DepositFeeCredits
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for DepositFeeCredits
impl BorshSerialize for DepositFeeCredits
Sourceimpl Discriminator for DepositFeeCredits
impl Discriminator for DepositFeeCredits
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for DepositFeeCredits
impl InstructionData for DepositFeeCredits