pub struct InitializeMarket {
pub init_slot: u64,
pub init_oracle_price: u64,
pub params: RiskParamsInput,
}Expand description
Instruction.
Fields
init_slot: u64init_oracle_price: u64params: RiskParamsInputTrait Implementations
Sourceimpl BorshDeserialize for InitializeMarket
impl BorshDeserialize for InitializeMarket
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for InitializeMarket
impl BorshSerialize for InitializeMarket
Sourceimpl Discriminator for InitializeMarket
impl Discriminator for InitializeMarket
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for InitializeMarket
impl InstructionData for InitializeMarket