pub struct Liquidate {
pub account_idx: u16,
pub funding_rate: i64,
}Expand description
Instruction.
Fields
account_idx: u16funding_rate: i64Trait Implementations
Sourceimpl BorshDeserialize for Liquidate
impl BorshDeserialize for Liquidate
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Liquidate
impl BorshSerialize for Liquidate
Sourceimpl Discriminator for Liquidate
impl Discriminator for Liquidate
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for Liquidate
impl InstructionData for Liquidate