pub struct TopUpInsurance {
pub amount: u64,
}Expand description
Instruction.
Fields
amount: u64Trait Implementations
Sourceimpl BorshDeserialize for TopUpInsurance
impl BorshDeserialize for TopUpInsurance
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TopUpInsurance
impl BorshSerialize for TopUpInsurance
Sourceimpl Discriminator for TopUpInsurance
impl Discriminator for TopUpInsurance
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for TopUpInsurance
impl InstructionData for TopUpInsurance