pub struct Trade {
pub account_a: u16,
pub account_b: u16,
pub size_q: i128,
pub exec_price: u64,
pub funding_rate: i64,
}Expand description
Instruction.
Fields
account_a: u16account_b: u16size_q: i128exec_price: u64funding_rate: i64Trait Implementations
Sourceimpl BorshDeserialize for Trade
impl BorshDeserialize for Trade
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Trade
impl BorshSerialize for Trade
Sourceimpl Discriminator for Trade
impl Discriminator for Trade
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for Trade
impl InstructionData for Trade