pub struct DepositFeeCredits<'info> {
pub user: Signer<'info>,
pub market: UncheckedAccount<'info>,
pub mint: Account<'info, Mint>,
pub user_token_account: Account<'info, TokenAccount>,
pub vault: Account<'info, TokenAccount>,
pub token_program: Program<'info, Token>,
}Fields
user: Signer<'info>market: UncheckedAccount<'info>CHECK: Validated via owner, discriminator, and size.
mint: Account<'info, Mint>user_token_account: Account<'info, TokenAccount>User’s token account to transfer from.
vault: Account<'info, TokenAccount>Vault token account to transfer into.
token_program: Program<'info, Token>Trait Implementations
Sourceimpl<'info> Accounts<'info, DepositFeeCreditsBumps> for DepositFeeCredits<'info>where
'info: 'info,
impl<'info> Accounts<'info, DepositFeeCreditsBumps> for DepositFeeCredits<'info>where
'info: 'info,
Sourcefn try_accounts(
__program_id: &Pubkey,
__accounts: &mut &'info [AccountInfo<'info>],
__ix_data: &[u8],
__bumps: &mut DepositFeeCreditsBumps,
__reallocs: &mut BTreeSet<Pubkey>,
) -> Result<Self>
fn try_accounts( __program_id: &Pubkey, __accounts: &mut &'info [AccountInfo<'info>], __ix_data: &[u8], __bumps: &mut DepositFeeCreditsBumps, __reallocs: &mut BTreeSet<Pubkey>, ) -> Result<Self>
Returns the validated accounts struct. What constitutes “valid” is
program dependent. However, users of these types should never have to
worry about account substitution attacks. For example, if a program
expects a
Mint account from the SPL token program in a particular
field, then it should be impossible for this method to return Ok if
any other account type is given–from the SPL token program or elsewhere. Read moreSourceimpl<'info> AccountsExit<'info> for DepositFeeCredits<'info>where
'info: 'info,
impl<'info> AccountsExit<'info> for DepositFeeCredits<'info>where
'info: 'info,
Sourceimpl<'info> Bumps for DepositFeeCredits<'info>where
'info: 'info,
impl<'info> Bumps for DepositFeeCredits<'info>where
'info: 'info,
Sourcetype Bumps = DepositFeeCreditsBumps
type Bumps = DepositFeeCreditsBumps
Struct to hold account bump seeds.
Sourceimpl<'info> DuplicateMutableAccountKeys for DepositFeeCredits<'info>where
'info: 'info,
impl<'info> DuplicateMutableAccountKeys for DepositFeeCredits<'info>where
'info: 'info,
fn duplicate_mutable_account_keys(&self) -> Vec<Pubkey>
Sourceimpl<'info> ToAccountInfos<'info> for DepositFeeCredits<'info>where
'info: 'info,
impl<'info> ToAccountInfos<'info> for DepositFeeCredits<'info>where
'info: 'info,
fn to_account_infos(&self) -> Vec<AccountInfo<'info>>
Sourceimpl<'info> ToAccountMetas for DepositFeeCredits<'info>
impl<'info> ToAccountMetas for DepositFeeCredits<'info>
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl<'info> Freeze for DepositFeeCredits<'info>
impl<'info> !RefUnwindSafe for DepositFeeCredits<'info>
impl<'info> !Send for DepositFeeCredits<'info>
impl<'info> !Sync for DepositFeeCredits<'info>
impl<'info> Unpin for DepositFeeCredits<'info>
impl<'info> UnsafeUnpin for DepositFeeCredits<'info>
impl<'info> !UnwindSafe for DepositFeeCredits<'info>