pub struct AuthorityTransferInitiated {
pub market: Pubkey,
pub old_authority: Pubkey,
pub pending_authority: Pubkey,
}Fields
market: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for AuthorityTransferInitiated
impl BorshDeserialize for AuthorityTransferInitiated
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for AuthorityTransferInitiated
impl Discriminator for AuthorityTransferInitiated
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more