pub struct Deposited {
pub user: Pubkey,
pub account_idx: u16,
pub amount: u64,
}Fields
user: Pubkeyaccount_idx: u16amount: u64Trait Implementations
Sourceimpl BorshDeserialize for Deposited
impl BorshDeserialize for Deposited
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Deposited
impl BorshSerialize for Deposited
Sourceimpl Discriminator for Deposited
impl Discriminator for Deposited
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more