pub struct MarketAccrued {
pub signer: Pubkey,
pub oracle_price: u64,
pub slot: u64,
}Fields
signer: Pubkeyoracle_price: u64slot: u64Trait Implementations
Sourceimpl BorshDeserialize for MarketAccrued
impl BorshDeserialize for MarketAccrued
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for MarketAccrued
impl BorshSerialize for MarketAccrued
Sourceimpl Discriminator for MarketAccrued
impl Discriminator for MarketAccrued
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more