pub struct MarketInitialized {
pub authority: Pubkey,
pub mint: Pubkey,
pub oracle: Pubkey,
pub matcher: Pubkey,
pub init_slot: u64,
pub init_oracle_price: u64,
}Fields
mint: Pubkeyoracle: Pubkeymatcher: Pubkeyinit_slot: u64init_oracle_price: u64Trait Implementations
Sourceimpl BorshDeserialize for MarketInitialized
impl BorshDeserialize for MarketInitialized
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for MarketInitialized
impl BorshSerialize for MarketInitialized
Sourceimpl Discriminator for MarketInitialized
impl Discriminator for MarketInitialized
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more