pub struct MatcherUpdated {
pub authority: Pubkey,
pub old_matcher: Pubkey,
pub new_matcher: Pubkey,
}Fields
old_matcher: Pubkeynew_matcher: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for MatcherUpdated
impl BorshDeserialize for MatcherUpdated
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for MatcherUpdated
impl BorshSerialize for MatcherUpdated
Sourceimpl Discriminator for MatcherUpdated
impl Discriminator for MatcherUpdated
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more