pub struct PnlConverted {
pub user: Pubkey,
pub account_idx: u16,
pub x_req: u64,
}Fields
user: Pubkeyaccount_idx: u16x_req: u64Trait Implementations
Sourceimpl BorshDeserialize for PnlConverted
impl BorshDeserialize for PnlConverted
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for PnlConverted
impl BorshSerialize for PnlConverted
Sourceimpl Discriminator for PnlConverted
impl Discriminator for PnlConverted
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more