pub struct TradeExecuted {
pub matcher: Pubkey,
pub account_a: u16,
pub account_b: u16,
pub size_q: i128,
pub exec_price: u64,
}Fields
matcher: Pubkeyaccount_a: u16account_b: u16size_q: i128exec_price: u64Trait Implementations
Sourceimpl BorshDeserialize for TradeExecuted
impl BorshDeserialize for TradeExecuted
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TradeExecuted
impl BorshSerialize for TradeExecuted
Sourceimpl Discriminator for TradeExecuted
impl Discriminator for TradeExecuted
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more