pub struct Withdrawn {
pub user: Pubkey,
pub account_idx: u16,
pub amount: u64,
}Fields
user: Pubkeyaccount_idx: u16amount: u64Trait Implementations
Sourceimpl BorshDeserialize for Withdrawn
impl BorshDeserialize for Withdrawn
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Withdrawn
impl BorshSerialize for Withdrawn
Sourceimpl Discriminator for Withdrawn
impl Discriminator for Withdrawn
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more