Module accounts

Module accounts 

An Anchor generated module, providing a set of structs mirroring the structs deriving Accounts, where each field is a Pubkey. This is useful for specifying accounts for a client.

Structs

CloseAccount
Generated client accounts for CloseAccount.
Crank
Generated client accounts for Crank.
Deposit
Generated client accounts for Deposit.
InitializeMarket
Generated client accounts for InitializeMarket.
Liquidate
Generated client accounts for Liquidate.
Settle
Generated client accounts for Settle.
Trade
Generated client accounts for Trade.
Withdraw
Generated client accounts for Withdraw.