pub struct Withdraw {
pub user: Pubkey,
pub market: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for Withdraw.
Fields
user: Pubkeymarket: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for Withdraw
impl BorshSerialize for Withdraw
Sourceimpl ToAccountMetas for Withdraw
impl ToAccountMetas for Withdraw
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for Withdraw
impl RefUnwindSafe for Withdraw
impl Send for Withdraw
impl Sync for Withdraw
impl Unpin for Withdraw
impl UnsafeUnpin for Withdraw
impl UnwindSafe for Withdraw