An Anchor generated module containing the program’s set of
instructions, where each method handler in the #[program] mod is
associated with a struct defining the input arguments to the
method. These should be used directly, when one wants to serialize
Anchor instruction data, for example, when specifying
instructions on a client.
Structs
- Close
Account - Instruction.
- Crank
- Instruction.
- Deposit
- Instruction.
- Initialize
Market - Instruction.
- Liquidate
- Instruction.
- Settle
- Instruction.
- Trade
- Instruction.
- Withdraw
- Instruction.