Structs
- Market
Header - Market account header — stored at the beginning of the account data. The RiskEngine state follows immediately after, accessed via raw pointer because RiskEngine is ~1.165 MB and doesn’t derive Copy.
Constants
- MARKET_
ACCOUNT_ SIZE - Total account size: discriminator + header + engine
Functions
- engine_
from_ account_ data - Helper to get a mutable reference to the RiskEngine from raw account data.
- engine_
from_ account_ data_ ref - header_
from_ account_ data - market_
signer_ seeds - Market PDA signer seeds: [b“market“, authority_key, &[bump]]
- write_
header